/***********************************************************************
************************************************************************/
#ifndef	_GIF_RGB_H_
#define	_GIF_RGB_H_

#ifdef WIN_BMP
typedef struct{
	unsigned char b;
	unsigned char g;
	unsigned char r;
	unsigned char x;
}RGB4;
#else
typedef struct{
	unsigned char r;
	unsigned char g;	
	unsigned char b;
	unsigned char x;
}RGB4;
#endif

typedef struct{
	RGB4 color[256];
}ColorMap;

typedef struct gif_rgb {
	unsigned char r;
	unsigned char g;
	unsigned char b;
}GIF_RGB;

int     GetColorInt(unsigned char r, unsigned char g, unsigned char b);
int	GetColorRGB(RGB4 *rgb);

typedef struct{
	ColorMap cmap;
	int width;
	int height;	
}GIF_ENV;

#endif
